@@ -11,7 +11,15 @@ ALL_ROUTES = [
 
     ('call-api', 'SoftLayer.CLI.call_api:cli'),
 
+    ('account', 'SoftLayer.CLI.account'),
+    ('account:invoice-detail', 'SoftLayer.CLI.account.invoice_detail:cli'),
+    ('account:invoices', 'SoftLayer.CLI.account.invoices:cli'),
+    ('account:events', 'SoftLayer.CLI.account.events:cli'),
+    ('account:event-detail', 'SoftLayer.CLI.account.event_detail:cli'),
+    ('account:summary', 'SoftLayer.CLI.account.summary:cli'),
+
     ('virtual', 'SoftLayer.CLI.virt'),
+    ('virtual:bandwidth', 'SoftLayer.CLI.virt.bandwidth:cli'),
     ('virtual:cancel', 'SoftLayer.CLI.virt.cancel:cli'),
     ('virtual:capture', 'SoftLayer.CLI.virt.capture:cli'),
     ('virtual:create', 'SoftLayer.CLI.virt.create:cli'),
@@ -29,6 +37,7 @@ ALL_ROUTES = [
     ('virtual:reboot', 'SoftLayer.CLI.virt.power:reboot'),
     ('virtual:reload', 'SoftLayer.CLI.virt.reload:cli'),
     ('virtual:upgrade', 'SoftLayer.CLI.virt.upgrade:cli'),
+    ('virtual:usage', 'SoftLayer.CLI.virt.usage:cli'),
     ('virtual:credentials', 'SoftLayer.CLI.virt.credentials:cli'),
     ('virtual:capacity', 'SoftLayer.CLI.virt.capacity:cli'),
     ('virtual:placementgroup', 'SoftLayer.CLI.virt.placementgroup:cli'),
@@ -45,7 +54,6 @@ ALL_ROUTES = [
     ('cdn', 'SoftLayer.CLI.cdn'),
     ('cdn:detail', 'SoftLayer.CLI.cdn.detail:cli'),
     ('cdn:list', 'SoftLayer.CLI.cdn.list:cli'),
-    ('cdn:load', 'SoftLayer.CLI.cdn.load:cli'),
     ('cdn:origin-add', 'SoftLayer.CLI.cdn.origin_add:cli'),
     ('cdn:origin-list', 'SoftLayer.CLI.cdn.origin_list:cli'),
     ('cdn:origin-remove', 'SoftLayer.CLI.cdn.origin_remove:cli'),
@@ -76,15 +84,13 @@ ALL_ROUTES = [
     ('block:replica-failover', 'SoftLayer.CLI.block.replication.failover:cli'),
     ('block:replica-order', 'SoftLayer.CLI.block.replication.order:cli'),
     ('block:replica-partners', 'SoftLayer.CLI.block.replication.partners:cli'),
-    ('block:replica-locations',
-     'SoftLayer.CLI.block.replication.locations:cli'),
+    ('block:replica-locations', 'SoftLayer.CLI.block.replication.locations:cli'),
     ('block:snapshot-cancel', 'SoftLayer.CLI.block.snapshot.cancel:cli'),
     ('block:snapshot-create', 'SoftLayer.CLI.block.snapshot.create:cli'),
     ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot.delete:cli'),
     ('block:snapshot-disable', 'SoftLayer.CLI.block.snapshot.disable:cli'),
     ('block:snapshot-enable', 'SoftLayer.CLI.block.snapshot.enable:cli'),
-    ('block:snapshot-schedule-list',
-     'SoftLayer.CLI.block.snapshot.schedule_list:cli'),
+    ('block:snapshot-schedule-list', 'SoftLayer.CLI.block.snapshot.schedule_list:cli'),
     ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot.list:cli'),
     ('block:snapshot-order', 'SoftLayer.CLI.block.snapshot.order:cli'),
     ('block:snapshot-restore', 'SoftLayer.CLI.block.snapshot.restore:cli'),
@@ -115,8 +121,7 @@ ALL_ROUTES = [
     ('file:snapshot-delete', 'SoftLayer.CLI.file.snapshot.delete:cli'),
     ('file:snapshot-disable', 'SoftLayer.CLI.file.snapshot.disable:cli'),
     ('file:snapshot-enable', 'SoftLayer.CLI.file.snapshot.enable:cli'),
-    ('file:snapshot-schedule-list',
-     'SoftLayer.CLI.file.snapshot.schedule_list:cli'),
+    ('file:snapshot-schedule-list', 'SoftLayer.CLI.file.snapshot.schedule_list:cli'),
     ('file:snapshot-list', 'SoftLayer.CLI.file.snapshot.list:cli'),
     ('file:snapshot-order', 'SoftLayer.CLI.file.snapshot.order:cli'),
     ('file:snapshot-restore', 'SoftLayer.CLI.file.snapshot.restore:cli'),
@@ -157,29 +162,29 @@ ALL_ROUTES = [
     ('ipsec:subnet-add', 'SoftLayer.CLI.vpn.ipsec.subnet.add:cli'),
     ('ipsec:subnet-remove', 'SoftLayer.CLI.vpn.ipsec.subnet.remove:cli'),
     ('ipsec:translation-add', 'SoftLayer.CLI.vpn.ipsec.translation.add:cli'),
-    ('ipsec:translation-remove',
-     'SoftLayer.CLI.vpn.ipsec.translation.remove:cli'),
-    ('ipsec:translation-update',
-     'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
+    ('ipsec:translation-remove', 'SoftLayer.CLI.vpn.ipsec.translation.remove:cli'),
+    ('ipsec:translation-update', 'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
     ('ipsec:update', 'SoftLayer.CLI.vpn.ipsec.update:cli'),
 
     ('loadbal', 'SoftLayer.CLI.loadbal'),
-    ('loadbal:cancel', 'SoftLayer.CLI.loadbal.cancel:cli'),
-    ('loadbal:create', 'SoftLayer.CLI.loadbal.create:cli'),
-    ('loadbal:create-options', 'SoftLayer.CLI.loadbal.create_options:cli'),
     ('loadbal:detail', 'SoftLayer.CLI.loadbal.detail:cli'),
-    ('loadbal:group-add', 'SoftLayer.CLI.loadbal.group_add:cli'),
-    ('loadbal:group-delete', 'SoftLayer.CLI.loadbal.group_delete:cli'),
-    ('loadbal:group-edit', 'SoftLayer.CLI.loadbal.group_edit:cli'),
-    ('loadbal:group-reset', 'SoftLayer.CLI.loadbal.group_reset:cli'),
-    ('loadbal:health-checks', 'SoftLayer.CLI.loadbal.health_checks:cli'),
     ('loadbal:list', 'SoftLayer.CLI.loadbal.list:cli'),
-    ('loadbal:routing-methods', 'SoftLayer.CLI.loadbal.routing_methods:cli'),
-    ('loadbal:routing-types', 'SoftLayer.CLI.loadbal.routing_types:cli'),
-    ('loadbal:service-add', 'SoftLayer.CLI.loadbal.service_add:cli'),
-    ('loadbal:service-delete', 'SoftLayer.CLI.loadbal.service_delete:cli'),
-    ('loadbal:service-edit', 'SoftLayer.CLI.loadbal.service_edit:cli'),
-    ('loadbal:service-toggle', 'SoftLayer.CLI.loadbal.service_toggle:cli'),
+    ('loadbal:health', 'SoftLayer.CLI.loadbal.health:cli'),
+    ('loadbal:member-add', 'SoftLayer.CLI.loadbal.members:add'),
+    ('loadbal:member-del', 'SoftLayer.CLI.loadbal.members:remove'),
+    ('loadbal:pool-add', 'SoftLayer.CLI.loadbal.pools:add'),
+    ('loadbal:pool-edit', 'SoftLayer.CLI.loadbal.pools:edit'),
+    ('loadbal:pool-del', 'SoftLayer.CLI.loadbal.pools:delete'),
+    ('loadbal:l7pool-add', 'SoftLayer.CLI.loadbal.pools:l7pool_add'),
+    ('loadbal:l7pool-del', 'SoftLayer.CLI.loadbal.pools:l7pool_del'),
+    ('loadbal:order', 'SoftLayer.CLI.loadbal.order:order'),
+    ('loadbal:order-options', 'SoftLayer.CLI.loadbal.order:order_options'),
+    ('loadbal:cancel', 'SoftLayer.CLI.loadbal.order:cancel'),
+
+
+    ('loadbal:ns-detail', 'SoftLayer.CLI.loadbal.ns_detail:cli'),
+    ('loadbal:ns-list', 'SoftLayer.CLI.loadbal.ns_list:cli'),
+
 
     ('metadata', 'SoftLayer.CLI.metadata:cli'),
 
@@ -188,10 +193,10 @@ ALL_ROUTES = [
     ('nas:credentials', 'SoftLayer.CLI.nas.credentials:cli'),
 
     ('object-storage', 'SoftLayer.CLI.object_storage'),
-    ('object-storage:accounts',
-     'SoftLayer.CLI.object_storage.list_accounts:cli'),
-    ('object-storage:endpoints',
-     'SoftLayer.CLI.object_storage.list_endpoints:cli'),
+
+    ('object-storage:accounts', 'SoftLayer.CLI.object_storage.list_accounts:cli'),
+    ('object-storage:endpoints', 'SoftLayer.CLI.object_storage.list_endpoints:cli'),
+    ('object-storage:credential', 'SoftLayer.CLI.object_storage.credential:cli'),
 
     ('order', 'SoftLayer.CLI.order'),
     ('order:category-list', 'SoftLayer.CLI.order.category_list:cli'),
@@ -201,12 +206,16 @@ ALL_ROUTES = [
     ('order:preset-list', 'SoftLayer.CLI.order.preset_list:cli'),
     ('order:package-locations', 'SoftLayer.CLI.order.package_locations:cli'),
     ('order:place-quote', 'SoftLayer.CLI.order.place_quote:cli'),
+    ('order:quote-list', 'SoftLayer.CLI.order.quote_list:cli'),
+    ('order:quote-detail', 'SoftLayer.CLI.order.quote_detail:cli'),
+    ('order:quote', 'SoftLayer.CLI.order.quote:cli'),
 
     ('rwhois', 'SoftLayer.CLI.rwhois'),
     ('rwhois:edit', 'SoftLayer.CLI.rwhois.edit:cli'),
     ('rwhois:show', 'SoftLayer.CLI.rwhois.show:cli'),
 
     ('hardware', 'SoftLayer.CLI.hardware'),
+    ('hardware:bandwidth', 'SoftLayer.CLI.hardware.bandwidth:cli'),
     ('hardware:cancel', 'SoftLayer.CLI.hardware.cancel:cli'),
     ('hardware:cancel-reasons', 'SoftLayer.CLI.hardware.cancel_reasons:cli'),
     ('hardware:create', 'SoftLayer.CLI.hardware.create:cli'),
