@@ -9,7 +9,6 @@ import logging
 import socket
 import time
 
-
 import SoftLayer
 from SoftLayer.decoration import retry
 from SoftLayer.managers import ordering
@@ -86,14 +85,17 @@ class HardwareManager(utils.IdentifierMixin, object):
             raise SoftLayer.SoftLayerError("Unable to cancel hardware with running transaction")
 
         if 'billingItem' not in hw_billing:
-            raise SoftLayer.SoftLayerError("Ticket #%s already exists for this server" %
-                                           hw_billing['openCancellationTicket']['id'])
+            if utils.lookup(hw_billing, 'openCancellationTicket', 'id'):
+                raise SoftLayer.SoftLayerError("Ticket #%s already exists for this server" %
+                                               hw_billing['openCancellationTicket']['id'])
+            raise SoftLayer.SoftLayerError("Cannot locate billing for the server. "
+                                           "The server may already be cancelled.")
 
         billing_id = hw_billing['billingItem']['id']
 
         if immediate and not hw_billing['hourlyBillingFlag']:
-            LOGGER.warning("Immediate cancelation of montly servers is not guaranteed."
-                           "Please check the cancelation ticket for updates.")
+            LOGGER.warning("Immediate cancellation of monthly servers is not guaranteed."
+                           "Please check the cancellation ticket for updates.")
 
             result = self.client.call('Billing_Item', 'cancelItem',
                                       False, False, cancel_reason, comment, id=billing_id)
@@ -664,6 +666,40 @@ class HardwareManager(utils.IdentifierMixin, object):
         LOGGER.info("Waiting for %d expired.", instance_id)
         return False
 
+    def get_tracking_id(self, instance_id):
+        """Returns the Metric Tracking Object Id for a hardware server
+
+        :param int instance_id: Id of the hardware server
+        """
+        return self.hardware.getMetricTrackingObjectId(id=instance_id)
+
+    def get_bandwidth_data(self, instance_id, start_date=None, end_date=None, direction=None, rollup=3600):
+        """Gets bandwidth data for a server
+
+        Will get averaged bandwidth data for a given time period. If you use a rollup over 3600 be aware
+        that the API will bump your start/end date to align with how data is stored. For example if you
+        have a rollup of 86400 your start_date will be bumped to 00:00. If you are not using a time in the
+        start/end date fields, this won't really matter.
+
+        :param int instance_id: Hardware Id to get data for
+        :param date start_date: Date to start pulling data for.
+        :param date end_date: Date to finish pulling data for
+        :param string direction: Can be either 'public', 'private', or None for both.
+        :param int rollup: 300, 600, 1800, 3600, 43200 or 86400 seconds to average data over.
+        """
+        tracking_id = self.get_tracking_id(instance_id)
+        data = self.client.call('Metric_Tracking_Object', 'getBandwidthData', start_date, end_date, direction,
+                                rollup, id=tracking_id, iter=True)
+        return data
+
+    def get_bandwidth_allocation(self, instance_id):
+        """Combines getBandwidthAllotmentDetail() and getBillingCycleBandwidthUsage() """
+        a_mask = "mask[allocation[amount]]"
+        allotment = self.client.call('Hardware_Server', 'getBandwidthAllotmentDetail', id=instance_id, mask=a_mask)
+        u_mask = "mask[amountIn,amountOut,type]"
+        useage = self.client.call('Hardware_Server', 'getBillingCycleBandwidthUsage', id=instance_id, mask=u_mask)
+        return {'allotment': allotment.get('allocation'), 'useage': useage}
+
 
 def _get_extra_price_id(items, key_name, hourly, location):
     """Returns a price id attached to item with the given key_name."""
