@@ -61,7 +61,7 @@ class VSManager(utils.IdentifierMixin, object):
     def list_instances(self, hourly=True, monthly=True, tags=None, cpus=None,
                        memory=None, hostname=None, domain=None,
                        local_disk=None, datacenter=None, nic_speed=None,
-                       public_ip=None, private_ip=None, **kwargs):
+                       public_ip=None, private_ip=None, transient=None, **kwargs):
         """Retrieve a list of all virtual servers on the account.
 
         Example::
@@ -88,6 +88,7 @@ class VSManager(utils.IdentifierMixin, object):
         :param integer nic_speed: filter based on network speed (in MBPS)
         :param string public_ip: filter based on public ip address
         :param string private_ip: filter based on private ip address
+        :param boolean transient: filter on transient or non-transient instances
         :param dict \\*\\*kwargs: response-level options (mask, limit, etc.)
         :returns: Returns a list of dictionaries representing the matching
                   virtual servers
@@ -157,6 +158,11 @@ class VSManager(utils.IdentifierMixin, object):
             _filter['virtualGuests']['primaryBackendIpAddress'] = (
                 utils.query_filter(private_ip))
 
+        if transient is not None:
+            _filter['virtualGuests']['transientGuestFlag'] = (
+                utils.query_filter(bool(transient))
+            )
+
         kwargs['filter'] = _filter.to_dict()
         kwargs['iter'] = True
         return self.client.call('Account', call, **kwargs)
@@ -194,6 +200,7 @@ class VSManager(utils.IdentifierMixin, object):
                 'provisionDate,'
                 'notes,'
                 'dedicatedAccountHostOnlyFlag,'
+                'transientGuestFlag,'
                 'privateNetworkOnlyFlag,'
                 'primaryBackendIpAddress,'
                 'primaryIpAddress,'
@@ -312,7 +319,7 @@ class VSManager(utils.IdentifierMixin, object):
             private_subnet=None, public_subnet=None,
             userdata=None, nic_speed=None, disks=None, post_uri=None,
             private=False, ssh_keys=None, public_security_groups=None,
-            private_security_groups=None, boot_mode=None, **kwargs):
+            private_security_groups=None, boot_mode=None, transient=False, **kwargs):
         """Returns a dict appropriate to pass into Virtual_Guest::createObject
 
             See :func:`create_instance` for a list of available options.
@@ -362,6 +369,9 @@ class VSManager(utils.IdentifierMixin, object):
         if private:
             data['privateNetworkOnlyFlag'] = private
 
+        if transient:
+            data['transientGuestFlag'] = transient
+
         if image_id:
             data["blockDeviceTemplateGroup"] = {"globalIdentifier": image_id}
         elif os_code:
@@ -505,6 +515,7 @@ class VSManager(utils.IdentifierMixin, object):
                 'flavor': 'BL1_1X2X100'
                 'dedicated': False,
                 'private': False,
+                'transient': False,
                 'os_code' : u'UBUNTU_LATEST',
                 'hourly': True,
                 'ssh_keys': [1234],
@@ -883,6 +894,7 @@ class VSManager(utils.IdentifierMixin, object):
                 'flavor': 'BL1_1X2X100'
                 'dedicated': False,
                 'private': False,
+                'transient': False,
                 'os_code' : u'UBUNTU_LATEST',
                 'hourly': True,
                 'ssh_keys': [1234],
@@ -1018,11 +1030,45 @@ class VSManager(utils.IdentifierMixin, object):
             }
         ]
 
-        metric_tracking_id = self.guest.getMetricTrackingObjectId(id=instance_id)
+        metric_tracking_id = self.get_tracking_id(instance_id)
 
         return self.client.call('Metric_Tracking_Object', 'getSummaryData', start_date, end_date, valid_types,
                                 summary_period, id=metric_tracking_id, iter=True)
 
+    def get_tracking_id(self, instance_id):
+        """Returns the Metric Tracking Object Id for a hardware server
+
+        :param int instance_id: Id of the hardware server
+        """
+        return self.guest.getMetricTrackingObjectId(id=instance_id)
+
+    def get_bandwidth_data(self, instance_id, start_date=None, end_date=None, direction=None, rollup=3600):
+        """Gets bandwidth data for a server
+
+        Will get averaged bandwidth data for a given time period. If you use a rollup over 3600 be aware
+        that the API will bump your start/end date to align with how data is stored. For example if you
+        have a rollup of 86400 your start_date will be bumped to 00:00. If you are not using a time in the
+        start/end date fields, this won't really matter.
+
+        :param int instance_id: Hardware Id to get data for
+        :param date start_date: Date to start pulling data for.
+        :param date end_date: Date to finish pulling data for
+        :param string direction: Can be either 'public', 'private', or None for both.
+        :param int rollup: 300, 600, 1800, 3600, 43200 or 86400 seconds to average data over.
+        """
+        tracking_id = self.get_tracking_id(instance_id)
+        data = self.client.call('Metric_Tracking_Object', 'getBandwidthData', start_date, end_date, direction,
+                                rollup, id=tracking_id, iter=True)
+        return data
+
+    def get_bandwidth_allocation(self, instance_id):
+        """Combines getBandwidthAllotmentDetail() and getBillingCycleBandwidthUsage() """
+        a_mask = "mask[allocation[amount]]"
+        allotment = self.client.call('Virtual_Guest', 'getBandwidthAllotmentDetail', id=instance_id, mask=a_mask)
+        u_mask = "mask[amountIn,amountOut,type]"
+        useage = self.client.call('Virtual_Guest', 'getBillingCycleBandwidthUsage', id=instance_id, mask=u_mask)
+        return {'allotment': allotment.get('allocation'), 'useage': useage}
+
     # pylint: disable=inconsistent-return-statements
     def _get_price_id_for_upgrade(self, package_items, option, value, public=True):
         """Find the price id for the option and value to upgrade.
