@@ -157,7 +157,7 @@ class TestCase(testtools.TestCase):
         """Set and return mock on the current client."""
         return self.mocks.set_mock(service, method)
 
-    def run_command(self, args=None, env=None, fixtures=True, fmt='json'):
+    def run_command(self, args=None, env=None, fixtures=True, fmt='json', stdin=None):
         """A helper that runs a SoftLayer CLI command.
 
         This returns a click.testing.Result object.
@@ -169,7 +169,7 @@ class TestCase(testtools.TestCase):
         args.insert(0, '--format=%s' % fmt)
 
         runner = testing.CliRunner()
-        return runner.invoke(core.cli, args=args, obj=env or self.env)
+        return runner.invoke(core.cli, args=args, input=stdin, obj=env or self.env)
 
 
 def call_has_props(call, props):
