@@ -7,6 +7,7 @@
 """
 import datetime
 import re
+import time
 
 import six
 
@@ -142,9 +143,9 @@ def format_event_log_date(date_string, utc):
         utc = "+0000"
 
     iso_time_zone = utc[:3] + ':' + utc[3:]
-    clean_time = "{}.000000{}".format(dirty_time, iso_time_zone)
+    cleaned_time = "{}.000000{}".format(dirty_time, iso_time_zone)
 
-    return clean_time
+    return cleaned_time
 
 
 def event_log_filter_between_date(start, end, utc):
@@ -288,3 +289,55 @@ def clean_string(string):
         return ''
     else:
         return " ".join(string.split())
+
+
+def clean_splitlines(string):
+    """Returns a string where \r\n is replaced with \n"""
+    if string is None:
+        return ''
+    else:
+        return "\n".join(string.splitlines())
+
+
+def clean_time(sltime, in_format='%Y-%m-%dT%H:%M:%S%z', out_format='%Y-%m-%d %H:%M'):
+    """Easy way to format time strings
+
+    :param string sltime: A softlayer formatted time string
+    :param string in_format: Datetime format for strptime
+    :param string out_format: Datetime format for strftime
+    """
+    if sltime is None:
+        return None
+    try:
+        clean = datetime.datetime.strptime(sltime, in_format)
+        return clean.strftime(out_format)
+    # The %z option only exists with py3.6+
+    except ValueError:
+        return sltime
+
+
+def timestamp(date):
+    """Converts a datetime to timestamp
+
+    :param datetime date:
+    :returns int: The timestamp of date.
+    """
+
+    _timestamp = time.mktime(date.timetuple())
+
+    return int(_timestamp)
+
+
+def days_to_datetime(days):
+    """Returns the datetime value of last N days.
+
+    :param int days: From 0 to N days
+    :returns int: The datetime of last N days or datetime.now() if days <= 0.
+    """
+
+    date = datetime.datetime.now()
+
+    if days > 0:
+        date -= datetime.timedelta(days=days)
+
+    return date
